# PROTO Game Asset Tools
# 2024 PROTOWLF, Licensed under GPL-3.0


bl_info = {
    "name": "PROTO Game Asset Tools",
    "author": "PROTOWLF",
    "version": (1, 0, 0),
    "blender": (4, 2, 0),
    "location": "3D View > Properties > PROTO",
    "description": "Tools for game assets, with fixed exports for Unreal/Source.",
    "category": "Import-Export",
    "doc_url" : "https://protowlf.com/"
    }

        
# import, reload if already imported
if "proto_fbx_init" not in locals():
    from .src.fbx_export import proto_fbx_init
    from .src import ui
    from .src import operators
    from .src import vertex_group_to_vertex_color
    #print("PROTO Tools: Importing")
else:
    import importlib
    proto_fbx_init = importlib.reload(proto_fbx_init)
    ui = importlib.reload(ui)
    operators = importlib.reload(operators)
    vertex_group_to_vertex_color = importlib.reload(vertex_group_to_vertex_color)
    #print("PROTO Tools: Reloading Scripts") 

import bpy
from bpy.app.handlers import persistent
 

def register():
    proto_fbx_init.register()
    ui.register()
    operators.register()
    vertex_group_to_vertex_color.register()
    

def unregister():
    proto_fbx_init.unregister()
    ui.unregister()
    operators.unregister()
    vertex_group_to_vertex_color.unregister()
    

if __name__ == "__main__":
    register()